@@ -16,7 +16,12 @@ found using
 
 help(laserbeamsize.m2)
 """
+__version__ = '1.9.2'
+__author__ = 'Scott Prahl'
+__email__ = 'scott.prahl@oit.edu'
+__copyright__ = 'Copyright 2017-22, Scott Prahl'
+__license__ = 'MIT'
+__url__ = 'https://github.com/scottprahl/laserbeamsize.git'
+
 from .laserbeamsize import *
 from .m2 import *
-
-__version__ = '1.9.1'
